@@ -5,6 +5,7 @@
 #' improve timings and UX.
 #'
 #' @family Cache
+#' @inheritParams get_mp3
 #' @param data Object
 #' @param base Character vector. Unique name for your cache file. You can pass
 #' a character vector with multiple elements that will be concatenated.
@@ -13,7 +14,6 @@
 #' @param cache_dir Character. Where do you want to save you cache files?
 #' By default they'll be stored on \code{tempdir()} but you can change it
 #' using this parameter or setting a global option called \code{"LARES_CACHE_DIR"}.
-#' @param quiet Boolean. Keep quiet? If not, message will be shown.
 #' @param ask Boolean. If cache exists, when reading: (interactive) ask the user
 #' if the cache should be used to proceed or ignored; when writing, (interactive)
 #' ask the user if the cache should be overwritten. Note that you can only ask for
@@ -34,7 +34,7 @@ cache_write <- function(data,
                         base = "temp",
                         cache_dir = getOption("LARES_CACHE_DIR"),
                         ask = FALSE,
-                        overwrite = NULL,
+                        overwrite = TRUE,
                         quiet = FALSE,
                         ...) {
   if (is.null(cache_dir)) {
@@ -54,12 +54,12 @@ cache_write <- function(data,
     } else {
       answer <- "use"
     }
-    if (answer != "i" && isTRUE(overwrite)) {
+    if (answer != "i" && !isFALSE(overwrite)) {
       saveRDS(data, file = file)
       if (!quiet) message("> Cache saved succesfully: ", base)
     } else {
       if (!quiet) message("> Skipped writing cache for: ", base)
-      return(invisible(NULL))
+      invisible(NULL)
     }
   } else {
     stop("Not a valid directory: ", cache_dir)
@@ -91,7 +91,7 @@ cache_read <- function(base,
     if (answer != "i" && isTRUE(overwrite)) {
       data <- readRDS(file)
       if (!quiet) message("> Cache loaded succesfully: ", base)
-      return(data)
+      data
     }
   } else {
     if (!quiet) {
@@ -101,7 +101,7 @@ cache_read <- function(base,
         message("No cache file found for ", base)
       }
     }
-    return(invisible(NULL))
+    invisible(NULL)
   }
 }
 
@@ -126,7 +126,7 @@ cache_exists <- function(base = NULL, cache_dir = getOption("LARES_CACHE_DIR"),
   attr(exists, "filename") <- filename
   attr(exists, "base") <- base
   attr(exists, "cache_dir") <- cache_dir
-  return(exists)
+  exists
 }
 
 #' @rdname cache_write
@@ -146,7 +146,7 @@ cache_clear <- function(cache_dir = getOption("LARES_CACHE_DIR"), quiet = FALSE,
       message("No cache files available to be removed.")
     }
   }
-  return(invisible(caches))
+  invisible(caches)
 }
 
 #' @rdname cache_write
@@ -155,13 +155,12 @@ cache_clear <- function(cache_dir = getOption("LARES_CACHE_DIR"), quiet = FALSE,
 #' @export
 cache_pipe <- function(data, base = "cache_pipe", read = TRUE, write = TRUE, ...) {
   if (isTRUE(read) && lares::cache_exists(base, ...)) {
-    y <- cache_read(base, ...)
-    return(y)
+    cache_read(base, ...)
   } else {
     if (isTRUE(write)) {
       data <- eval(data)
       cache_write(data, base, ...)
     }
-    return(data)
+    data
   }
 }
