@@ -2,15 +2,12 @@ encodeit <- function(x, from = "UTF-8", to = "latin1",
                      skip_class = "rpart.rules",
                      sub = "??") {
   if (skip_class %in% class(x)) {
-    return(x)
-  }
-  if ("list" %in% class(x)) {
-    return(lapply(x, encodeit))
-  }
-  if ("data.frame" %in% class(x)) {
-    return(data.frame(lapply(x, function(y) encodeit(y))))
-  }
-  if (any(c("factor", "character") %in% class(x))) {
+    x
+  } else if ("list" %in% class(x)) {
+    lapply(x, encodeit)
+  } else if ("data.frame" %in% class(x)) {
+    data.frame(lapply(x, function(y) encodeit(y)))
+  } else if (any(c("factor", "character") %in% class(x))) {
     is_factor <- class(x) %in% "factor"
     if (is_factor) levs <- levels(x)
     x <- as.character(x)
@@ -18,5 +15,5 @@ encodeit <- function(x, from = "UTF-8", to = "latin1",
     x <- gsub("(\\?){2,}", sub, x)
     if (is_factor) x <- factor(x, levels = encodeit(levs))
   }
-  return(x)
+  x
 }
